[Libreoffice-commits] .: sd/inc sd/source slideshow/source

Caolán McNamara caolan at kemper.freedesktop.org
Sun Dec 5 11:04:02 PST 2010


 sd/inc/Outliner.hxx                                    |    2 +-
 sd/source/ui/app/sdmod1.cxx                            |    2 +-
 sd/source/ui/inc/OutlinerIteratorImpl.hxx              |    4 ++--
 sd/source/ui/inc/tools/IconCache.hxx                   |    2 +-
 sd/source/ui/view/OutlinerIterator.cxx                 |    8 ++++----
 slideshow/source/engine/shapes/drawshapesubsetting.cxx |    6 +++---
 slideshow/source/inc/eventmultiplexer.hxx              |    2 +-
 slideshow/source/inc/usereventqueue.hxx                |    2 +-
 8 files changed, 14 insertions(+), 14 deletions(-)

New commits:
commit a74367262f20d5881c04abe71446bbe73fda3a93
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 13:10:34 2010 +0900

    Replace all occured, occurance etc.

diff --git a/sd/inc/Outliner.hxx b/sd/inc/Outliner.hxx
index 2a79841..ded3595 100644
--- a/sd/inc/Outliner.hxx
+++ b/sd/inc/Outliner.hxx
@@ -239,7 +239,7 @@ private:
     */
     bool mbFoundObject;
 
-    /** When set to <TRUE/> this flag indicates that an error has occured
+    /** When set to <TRUE/> this flag indicates that an error has occurred
         that should terminate the iteration over the objects to search/spell
         check.
     */
diff --git a/sd/source/ui/app/sdmod1.cxx b/sd/source/ui/app/sdmod1.cxx
index cbb099f..e0ca14c 100644
--- a/sd/source/ui/app/sdmod1.cxx
+++ b/sd/source/ui/app/sdmod1.cxx
@@ -978,7 +978,7 @@ OutlineToImpressFinalizer::OutlineToImpressFinalizer (
                     &nReadByteCount));
 
             // Check the error code and stop copying the stream data when an
-            // error has occured.
+            // error has occurred.
             switch (nErrorCode)
             {
                 case ERRCODE_NONE:
diff --git a/sd/source/ui/inc/tools/IconCache.hxx b/sd/source/ui/inc/tools/IconCache.hxx
index 198ed20..5a1e0d2 100644
--- a/sd/source/ui/inc/tools/IconCache.hxx
+++ b/sd/source/ui/inc/tools/IconCache.hxx
@@ -55,7 +55,7 @@ public:
     /** Return the icon with the given resource id.
         @return
             The returned Image may be empty when there is no icon for the
-            given id or an error occured.  Should not happen under normal
+            given id or an error occurred.  Should not happen under normal
             circumstances.
     */
     Image GetIcon (USHORT nResourceId);
diff --git a/sd/source/ui/view/OutlinerIterator.cxx b/sd/source/ui/view/OutlinerIterator.cxx
index bdcfabd..0d5ced1 100644
--- a/sd/source/ui/view/OutlinerIterator.cxx
+++ b/sd/source/ui/view/OutlinerIterator.cxx
@@ -581,7 +581,7 @@ ViewIteratorImpl::ViewIteratorImpl (
     const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward)
     : IteratorImplBase (pDocument, rpViewShellWeak, bDirectionIsForward),
-      mbPageChangeOccured(false),
+      mbPageChangeOccurred(false),
       mpPage(NULL),
       mpObjectIterator(NULL)
 {
@@ -599,7 +599,7 @@ ViewIteratorImpl::ViewIteratorImpl (
     PageKind ePageKind,
     EditMode eEditMode)
     : IteratorImplBase (pDocument, rpViewShellWeak, bDirectionIsForward, ePageKind, eEditMode),
-      mbPageChangeOccured(false),
+      mbPageChangeOccurred(false),
       mpPage(NULL),
       mpObjectIterator(NULL)
 {
@@ -696,8 +696,8 @@ void ViewIteratorImpl::GotoNextText(void)
 
 void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
 {
-    mbPageChangeOccured = (maPosition.mnPageIndex!=nPageIndex);
-    if (mbPageChangeOccured)
+    mbPageChangeOccurred = (maPosition.mnPageIndex!=nPageIndex);
+    if (mbPageChangeOccurred)
     {
         maPosition.mnPageIndex = nPageIndex;
 
diff --git a/slideshow/source/engine/shapes/drawshapesubsetting.cxx b/slideshow/source/engine/shapes/drawshapesubsetting.cxx
index 889e956..a5bb8c8 100644
--- a/slideshow/source/engine/shapes/drawshapesubsetting.cxx
+++ b/slideshow/source/engine/shapes/drawshapesubsetting.cxx
@@ -665,7 +665,7 @@ namespace slideshow
                 };
             }
 
-            /// Counts number of class occurences
+            /// Counts number of class occurrences
             class CountClassFunctor
             {
             public:
@@ -683,7 +683,7 @@ namespace slideshow
                     if( eCurrElemClassification == meClass )
                         ++mnCurrCount;
 
-                    return true; // never stop, count all occurences
+                    return true; // never stop, count all occurrences
                 }
 
                 sal_Int32 getCount() const
@@ -708,7 +708,7 @@ namespace slideshow
             // actions
             CountClassFunctor aFunctor( eRequestedClass );
 
-            // count all occurences in the given range
+            // count all occurrences in the given range
             iterateActionClassifications( aFunctor, rBegin, rEnd );
 
             return aFunctor.getCount();
diff --git a/slideshow/source/inc/eventmultiplexer.hxx b/slideshow/source/inc/eventmultiplexer.hxx
index 23b550a..aae1c40 100644
--- a/slideshow/source/inc/eventmultiplexer.hxx
+++ b/slideshow/source/inc/eventmultiplexer.hxx
@@ -61,7 +61,7 @@ struct EventMultiplexerImpl;
     are handled as well. Note that registered events which
     have a non-zero timeout (i.e. events that return non-zero
     from getActivationTime()) will not be fired immediately
-    after the user action occured, but only after the given
+    after the user action occurred, but only after the given
     timeout. Which is actually a feature.
 */
 class EventMultiplexer : private ::boost::noncopyable
diff --git a/slideshow/source/inc/usereventqueue.hxx b/slideshow/source/inc/usereventqueue.hxx
index c1d1f6c..e84f0dd 100644
--- a/slideshow/source/inc/usereventqueue.hxx
+++ b/slideshow/source/inc/usereventqueue.hxx
@@ -57,7 +57,7 @@ class MouseLeaveHandler;
     This class registeres at the EventMultiplexer and fires
     events registered for certain user actions. Note that all
     events will not be fired immediately after the user action
-    occured, but always added to the EventQueue (and fired the
+    occurred, but always added to the EventQueue (and fired the
     next time that queue is processed). Which is actually a
     feature.
     


More information about the Libreoffice-commits mailing list
diff --git a/sd/source/ui/inc/OutlinerIteratorImpl.hxx b/sd/source/ui/inc/OutlinerIteratorImpl.hxx
index 6b62b44..da51d1c 100644
--- a/sd/source/ui/inc/OutlinerIteratorImpl.hxx
+++ b/sd/source/ui/inc/OutlinerIteratorImpl.hxx
@@ -225,8 +225,8 @@ protected:
     void SetPage (sal_Int32 nPageIndex);
 
 private:
-    /// Indicates whether a page changed occured on switching to current page.
-    bool mbPageChangeOccured;
+    /// Indicates whether a page changed occurred on switching to current page.
+    bool mbPageChangeOccurred;
     /// Pointer to the page associated with the current page index. May be NULL.
     SdPage* mpPage;
     /// Iterator of all objects on the current page.